StockPiece

Struct StockPiece 

pub struct StockPiece {
    pub length: usize,
    pub price: usize,
    pub quantity: Option<usize>,
}
A rectangular stock piece that is available to cut one or more cut pieces from.

Fields

length: usize

Length of rectangular stock piece.

price: usize

Price to use to optimize for price when not all stock pieces are the same price per unit length. If optimizing for less waste instead, price can be set to 0 for all stock pieces.

quantity: Option<usize>

Quantity of this stock piece available for optimization. None means infinite quantity.